@@ -211,7 +211,9 @@ class ModelClient(object):
             minimum_reporting_units = model.get_minimum_reporting_units(alpha)
             if minimum_reporting_units > minimum_reporting_units_max:
                 minimum_reporting_units_max = minimum_reporting_units
-        # minimum_reporting_units_max += 1
+
+        if APP_ENV != "local" and save_results:
+            data.write_data(election_id, office)
 
         n_reporting_expected_units = reporting_units.shape[0]
         n_unexpected_units = unexpected_units.shape[0]
@@ -237,9 +239,6 @@ class ModelClient(object):
             aggregates, prediction_intervals, reporting_units, nonreporting_units, unexpected_units
         )
 
-        if APP_ENV != "local" and save_results:
-            data.write_data(election_id, office)
-
         for estimand in estimands:
             unit_predictions = model.get_unit_predictions(reporting_units, nonreporting_units, estimand)
             results_handler.add_unit_predictions(estimand, unit_predictions)
@@ -435,7 +434,7 @@ class HistoricalModelClient(ModelClient):
         aggregates = [a for a in aggregates if a != "unit"]
         for estimand in estimands:
             results_unit = preprocessed_data[
-                set(aggregates + ["postal_code", "geographic_unit_fips", f"results_{estimand}"])
+                list(set(aggregates + ["postal_code", "geographic_unit_fips", f"results_{estimand}"]))
             ].rename(columns={f"results_{estimand}": f"raw_results_{estimand}"})
             evaluation = {}
             evaluation["unit_data"] = self.compute_evaluation(
